summaryrefslogtreecommitdiff
path: root/src/basic/copy.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/basic/copy.h')
-rw-r--r--src/basic/copy.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/basic/copy.h b/src/basic/copy.h
index 8f5acdb7c..7c1d86fe3 100644
--- a/src/basic/copy.h
+++ b/src/basic/copy.h
@@ -13,9 +13,10 @@
#include <sys/types.h>
typedef enum CopyFlags {
- COPY_REFLINK = 1U << 0, /* Try to reflink */
- COPY_MERGE = 1U << 1, /* Merge existing trees with our new one to copy */
- COPY_REPLACE = 1U << 2, /* Replace an existing file if there's one */
+ COPY_REFLINK = 1U << 0, /* Try to reflink */
+ COPY_MERGE = 1U << 1, /* Merge existing trees with our new one to copy */
+ COPY_REPLACE = 1U << 2, /* Replace an existing file if there's one */
+ COPY_SAME_MOUNT = 1U << 3, /* Don't descend recursively into other file systems, across mount point boundaries */
} CopyFlags;
#if 0 /// UNNEEDED by elogind